This package includes an interactive SQL REPL that can be invoked by running `rock sql` without any arguments:

- Depends on the main `rockset` module to be already installed.

- `rock-sql` command line utility to interact, manage and operate Rockset from a shell command line.

- Once installed `rock-sql` can also be invoked by simply running `rock sql`.

Rockset documentation is available at:
http://docs.rockset.com


Attribution
===========

The `rock sql` REPL is heavily derived from the https://github.com/dbcli/pgcli project.
Our sincere gratitude and admiration to the authors and contributors of that project.

